@@ -12,7 +12,7 @@
 pm3datalist<-function(data,x,y,covs,factor=NULL){
   data<-as.data.frame(data)
   data<-na.omit(data)
-  if (!missing(factor)) {fac<-factor}
+  if (!missing(factor)) {factor<-factor}
   data[,x]<-as.numeric(as.factor(data[,x]))
   a<-unique(data[,x]);a<-sort(a);b<-c(1,2,3)
   if (identical(a,b) !=TRUE)  {stop("X must be 3 categories.If x is a number, it must be 1,2,3.")}
